@@ -38,8 +38,10 @@ gtfs <- set_servicepattern(gtfs)
 head(gtfs$.$servicepatterns)
 
 ## -----------------------------------------------------------------------------
+head(gtfs$.$dates_servicepatterns)
+
 # service ids used
-n_services <-  length(unique(gtfs$trips$service_id)) # 70
+n_services <- length(unique(gtfs$trips$service_id)) # 70
 
 # unique date patterns 
 n_servicepatterns <- length(unique(gtfs$.$servicepatterns$servicepattern_id)) # 7
@@ -153,7 +155,7 @@ ggplot(trip_dates_count, aes(x = weekday, y = -week_of_month)) + theme_bw() +
   geom_text(aes(label = day_of_month), size = 3, colour = "grey20") +
   facet_wrap(~month, ncol = 3) +
   scale_fill_gradient(low = "cornsilk1", high = "DarkOrange", na.value="white")+
-    scale_color_manual(guide = F, values = "grey50") +
+    scale_color_manual(guide = "none", values = "grey50") +
   theme(axis.text.y = element_blank(), axis.ticks.y = element_blank()) +
   theme(panel.grid = element_blank()) +
   labs(x = NULL, y = NULL, fill = "# trips") +
